pub struct FrameApiKeyMatcher(pub i16);Tuple Fields
0: i16Trait Implementations
Sourceimpl Clone for FrameApiKeyMatcher
impl Clone for FrameApiKeyMatcher
Sourcefn clone(&self) -> FrameApiKeyMatcher
fn clone(&self) -> FrameApiKeyMatcher
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FrameApiKeyMatcher
impl Debug for FrameApiKeyMatcher
Sourceimpl Default for FrameApiKeyMatcher
impl Default for FrameApiKeyMatcher
Sourcefn default() -> FrameApiKeyMatcher
fn default() -> FrameApiKeyMatcher
Returns the “default value” for a type. Read more
Sourceimpl Hash for FrameApiKeyMatcher
impl Hash for FrameApiKeyMatcher
Sourceimpl<State> Matcher<State, Frame> for FrameApiKeyMatcher
impl<State> Matcher<State, Frame> for FrameApiKeyMatcher
Sourcefn matches(
&self,
ext: Option<&mut Extensions>,
ctx: &Context<State>,
req: &Frame,
) -> bool
fn matches( &self, ext: Option<&mut Extensions>, ctx: &Context<State>, req: &Frame, ) -> bool
returns true on a match, false otherwise Read more
Sourcefn or<M>(self, other: M) -> impl Matcher<State, Request>
fn or<M>(self, other: M) -> impl Matcher<State, Request>
Provide an alternative matcher to match if the current one does not match.
Sourceimpl Ord for FrameApiKeyMatcher
impl Ord for FrameApiKeyMatcher
Sourcefn cmp(&self, other: &FrameApiKeyMatcher) -> Ordering
fn cmp(&self, other: &FrameApiKeyMatcher) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FrameApiKeyMatcher
impl PartialEq for FrameApiKeyMatcher
Sourceimpl PartialOrd for FrameApiKeyMatcher
impl PartialOrd for FrameApiKeyMatcher
impl Copy for FrameApiKeyMatcher
impl Eq for FrameApiKeyMatcher
impl StructuralPartialEq for FrameApiKeyMatcher