pub struct RequestFrameLayer;Trait Implementations
Sourceimpl Clone for RequestFrameLayer
impl Clone for RequestFrameLayer
Sourcefn clone(&self) -> RequestFrameLayer
fn clone(&self) -> RequestFrameLayer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequestFrameLayer
impl Debug for RequestFrameLayer
Sourceimpl Default for RequestFrameLayer
impl Default for RequestFrameLayer
Sourcefn default() -> RequestFrameLayer
fn default() -> RequestFrameLayer
Returns the “default value” for a type. Read more
Sourceimpl Hash for RequestFrameLayer
impl Hash for RequestFrameLayer
Sourceimpl<S> Layer<S> for RequestFrameLayer
impl<S> Layer<S> for RequestFrameLayer
Sourcetype Service = RequestFrameService<S>
type Service = RequestFrameService<S>
The service produced by the layer.
Sourcefn layer(&self, inner: S) -> Self::Service
fn layer(&self, inner: S) -> Self::Service
Wrap the given service with the middleware, returning a new service.
Sourcefn into_layer(self, inner: S) -> Self::Service
fn into_layer(self, inner: S) -> Self::Service
Same as
layer but consuming self after the service was created. Read moreSourceimpl Ord for RequestFrameLayer
impl Ord for RequestFrameLayer
Sourcefn cmp(&self, other: &RequestFrameLayer) -> Ordering
fn cmp(&self, other: &RequestFrameLayer) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RequestFrameLayer
impl PartialEq for RequestFrameLayer
Sourceimpl PartialOrd for RequestFrameLayer
impl PartialOrd for RequestFrameLayer
impl Copy for RequestFrameLayer
impl Eq for RequestFrameLayer
impl StructuralPartialEq for RequestFrameLayer